@@ -94,7 +94,7 @@ class Decompilation(Resource):
 
         If `directory` is ``None``, the current working directory is used.
         """
-        return self._get_file_and_save_it_to(
+        return self._get_file_and_save_it(
             self._path_to_output_file('hll'),
             directory
         )
@@ -119,7 +119,7 @@ class Decompilation(Resource):
 
         If `directory` is ``None``, the current working directory is used.
         """
-        return self._get_file_and_save_it_to(
+        return self._get_file_and_save_it(
             self._path_to_output_file('dsm'),
             directory
         )
@@ -196,11 +196,27 @@ class Decompilation(Resource):
 
         If `directory` is ``None``, the current working directory is used.
         """
-        return self._get_file_and_save_it_to(
+        return self._get_file_and_save_it(
             self._path_to_output_file('archive'),
             directory
         )
 
+    def save_binary(self, directory=None):
+        """Saves the compiled version of the input C file (provided that the
+        input was a C file) to the given directory.
+
+        :param str directory: Path to a directory in which the file will be
+            stored.
+
+        :returns: Path to the saved file (`str`).
+
+        If `directory` is ``None``, the current working directory is used.
+        """
+        return self._get_file_and_save_it(
+            self._path_to_output_file('binary'),
+            directory
+        )
+
     def _update_state(self):
         """Updates the state of the decompilation."""
         status = super()._update_state()
@@ -216,7 +232,8 @@ class Decompilation(Resource):
                 phase['name'],
                 phase['part'],
                 phase['description'],
-                phase['completion']
+                phase['completion'],
+                phase['warnings']
             ) for phase in status['phases']
         ]
 
