@@ -33,8 +33,19 @@ class Decompiler(Service):
         :param file_format: File format. The precise meaning depends on the
             used `mode`.
         :type file_format: str
+        :param comp_compiler: Compiler to be used when compiling input C source
+            files.
+        :type comp_compiler: str
+        :param comp_optimizations: Compiler optimizations to be used when
+            compiling input C source files.
+        :type comp_optimizations: str
+        :param comp_debug: Should the input C source file be compiled with
+            debugging information?
+        :type comp_debug: bool
+        :param comp_strip: Should the compiled input C source file be stripped?
+        :type comp_strip: bool
         :param generate_archive: Should an archive containing all outputs from
-            the decompilation be generated? Default: ``False``.
+            the decompilation be generated?
         :type generate_archive: bool
 
         :returns: Started decompilation
@@ -66,12 +77,16 @@ class Decompiler(Service):
         }
         self._add_pdb_file_when_given(files, kwargs)
         params = {
-            'mode': self._get_mode_param(files['input'], kwargs),
-            'generate_archive': self._get_generate_archive_param(kwargs)
+            'mode': self._get_mode_param(files['input'], kwargs)
         }
         self._add_param_when_given('target_language', params, kwargs)
         self._add_param_when_given('architecture', params, kwargs)
         self._add_param_when_given('file_format', params, kwargs)
+        self._add_param_when_given('comp_compiler', params, kwargs)
+        self._add_param_when_given('comp_debug', params, kwargs)
+        self._add_param_when_given('comp_strip', params, kwargs)
+        self._add_comp_optimizations_param_when_given(params, kwargs)
+        self._add_param_when_given('generate_archive', params, kwargs)
         response = conn.send_post_request(files=files, params=params)
         return response['id']
 
@@ -109,16 +124,18 @@ class Decompiler(Service):
         if value is not None:
             params[param] = value
 
-    def _get_generate_archive_param(self, kwargs):
-        """Returns whether an archive with all decompilation outputs should be
-        generated.
+    def _add_comp_optimizations_param_when_given(self, params, kwargs):
+        """Adds the ``comp_optimizations`` parameter to `params` when given in
+        `kwargs`.
         """
-        return self._get_param(
-            'generate_archive',
-            kwargs,
-            choices={True, False},
-            default=False
-        )
+        value = kwargs.get('comp_optimizations', None)
+        if value is not None:
+            # The retdec.com API expects the optimization level to start with a
+            # dash (e.g. "-O1" instead of just "O1"). To be user-friendly,
+            # allow passing just "O1" and add the dash automatically.
+            if not value.startswith('-'):
+                value = '-' + value
+            params['comp_optimizations'] = value
 
     def __repr__(self):
         return '<{} api_url={!r}>'.format(
