@@ -101,6 +101,7 @@ class ProgressLogDisplayer(ProgressDisplayer):
     """Displays a progress log during decompilation."""
 
     def __init__(self):
+        self._phases = []
         self._last_part = None
         self._last_phase_index = 0
         self._prologue_printed = False
@@ -143,6 +144,7 @@ class ProgressLogDisplayer(ProgressDisplayer):
 
         if d.has_finished():
             self._print_decompilation_end(d)
+            self._print_warnings_in_last_phase()
 
         # Make the output available as soon as possible.
         sys.stdout.flush()
@@ -162,15 +164,16 @@ class ProgressLogDisplayer(ProgressDisplayer):
 
     def _get_new_phases(self, d):
         """Returns new phases from the given decompilation."""
-        phases = d.get_phases()
-        return phases[self._last_phase_index:]
+        self._phases = d.get_phases()
+        return self._phases[self._last_phase_index:]
 
     def _print_phases(self, phases):
         """Prints the given phases."""
         for phase in phases:
-            # Print status for the last phase (if any).
+            # Print status and warnings for the last phase (if any).
             if self._last_phase_index > 0:
                 self._print_end_of_successful_phase()
+                self._print_warnings_in_last_phase()
             self._print_phase(phase)
             self._last_part = phase.part
             self._last_phase_index += 1
@@ -213,6 +216,21 @@ class ProgressLogDisplayer(ProgressDisplayer):
         """Prints the end of the current phase."""
         sys.stdout.write('[{}]\n'.format(status))
 
+    def _print_warnings_in_last_phase(self):
+        """Prints warnings from the last phase (if any)."""
+        if self._last_phase_index:
+            last_phase = self._phases[self._last_phase_index - 1]
+            self._print_warnings_in_phase(last_phase)
+
+    def _print_warnings_in_phase(self, phase):
+        """Prints warnings from the given phase (if any)."""
+        for warning in phase.warnings:
+            self._print_warning(warning)
+
+    def _print_warning(self, warning):
+        """Prints the given warning."""
+        sys.stdout.write('Warning: {}\n'.format(warning))
+
     def display_download_progress(self, file_name):
         # Example:
         #
@@ -275,6 +293,32 @@ def parse_args(argv):
         action='store_true',
         help='print fewer information during the decompilation'
     )
+    parser.add_argument(
+        '-c', '--compiler',
+        dest='comp_compiler',
+        choices=['gcc', 'clang'],
+        help='compiler to be used when compiling'
+    )
+    parser.add_argument(
+        '-C', '--compiler-optimizations',
+        dest='comp_optimizations',
+        choices=['O0', 'O1', 'O2', 'O3'],
+        help='compiler optimizations to be used when compiling'
+    )
+    parser.add_argument(
+        '-g', '--compiler-debug',
+        dest='comp_debug',
+        action='store_true',
+        default=None,
+        help='compile the input C file with debugging information'
+    )
+    parser.add_argument(
+        '-s', '--compiler-strip',
+        dest='comp_strip',
+        action='store_true',
+        default=None,
+        help='strip the compiled C file prior its decompilation'
+    )
     parser.add_argument(
         '-f', '--file-format',
         dest='file_format',
@@ -315,6 +359,7 @@ def parse_args(argv):
         '--with-archive',
         dest='generate_archive',
         action='store_true',
+        default=None,
         help='generate an archive containing all decompilation outputs'
     )
     parser.add_argument(
@@ -362,6 +407,17 @@ def add_decompilation_param_when_given(args, params, param_name):
         params[param_name] = param_value
 
 
+def should_download_output_binary_file(args):
+    """Should the compiled version of the input C file be downloaded?
+    """
+    # It should be downloaded only when we are decompiling a C file.
+    if args.mode == 'c':
+        return True
+    elif not args.mode and args.input_file.lower().endswith('c'):
+        return True
+    return False
+
+
 def main(argv=None):
     """Runs the tool.
 
@@ -383,6 +439,10 @@ def main(argv=None):
     add_decompilation_param_when_given(args, params, 'target_language')
     add_decompilation_param_when_given(args, params, 'architecture')
     add_decompilation_param_when_given(args, params, 'file_format')
+    add_decompilation_param_when_given(args, params, 'comp_compiler')
+    add_decompilation_param_when_given(args, params, 'comp_optimizations')
+    add_decompilation_param_when_given(args, params, 'comp_debug')
+    add_decompilation_param_when_given(args, params, 'comp_strip')
     add_decompilation_param_when_given(args, params, 'generate_archive')
     decompilation = decompiler.start_decompilation(**params)
 
@@ -400,6 +460,10 @@ def main(argv=None):
     file_path = decompilation.save_dsm_code(output_dir)
     display_download_progress(displayer, file_path)
 
+    if should_download_output_binary_file(args):
+        file_path = decompilation.save_binary(output_dir)
+        display_download_progress(displayer, file_path)
+
     if args.generate_archive:
         decompilation.wait_until_archive_is_generated()
         file_path = decompilation.save_archive(output_dir)
